// call the packages we need
let express       = require('express');
let bodyParser    = require('body-parser');
let oauth2Server  = require('oauth2-server');
let load          = require('express-load');
let MemoryStore   = require('./model');
let DynamicRoutes = require('./services/dynamicRoutes');

let app = express();
let ip = process.env.IP || 'localhost';
let port = process.env.PORT || 3000;
let address = ip + ':' + port;
let dynamicRoutes = new DynamicRoutes(app, address);

// configure app to use bodyParser()
// this will let us get the data from a POST
app.use(bodyParser.urlencoded({ extended: true }));
app.use(bodyParser.json());

// configure oauth2 sever
app.oauth = new oauth2Server({
    model: new MemoryStore(),
});

// configure cross origin
app.use(function(req, res, next) {
    res.header("Access-Control-Allow-Origin", "*");
    res.header("Access-Control-Allow-Headers", "*");
    res.header("Access-Control-Allow-Methods", "*");
    next();
});

// load routes
load('./routes').into(app);
dynamicRoutes.createRoutes();

// start server
app.listen(port);
console.log('Server started on ' + address);
